==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/link/lang/hr.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'hr', {
	acccessKey: 'Pristupna tipka',
	advanced: 'Napredno',
	advisoryContentType: 'Savjetodavna vrsta sadržaja',
	advisoryTitle: 'Savjetodavni naslov',
	anchor: {
		toolbar: 'Ubaci/promijeni sidro',
		menu: 'Svojstva sidra',
		title: 'Svojstva sidra',
		name: 'Ime sidra',
		errorName: 'Molimo unesite ime sidra',
		remove: 'Ukloni sidro'
	},
	anchorId: 'Po Id elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Kodna stranica povezanih resursa',
	cssClasses: 'Stylesheet klase',
	download: 'Preuzmi na silu',
	displayText: 'Prikaži tekst',
	emailAddress: 'E-Mail adresa',
	emailBody: 'Sadržaj poruke',
	emailSubject: 'Naslov',
	id: 'Id',
	info: 'Link Info',
	langCode: 'Smjer jezika',
	langDir: 'Smjer jezika',
	langDirLTR: 'S lijeva na desno (LTR)',
	langDirRTL: 'S desna na lijevo (RTL)',
	menu: 'Promijeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra)',
	noEmail: 'Molimo upišite e-mail adresu',
	noUrl: 'Molimo upišite URL link',
	noTel: 'Please type the phone number', // MISSING
	other: '<drugi>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Ovisno (Netscape)',
	popupFeatures: 'Mogućnosti popup prozora',
	popupFullScreen: 'Cijeli ekran (IE)',
	popupLeft: 'Lijeva pozicija',
	popupLocationBar: 'Traka za lokaciju',
	popupMenuBar: 'Izborna traka',
	popupResizable: 'Promjenjiva veličina',
	popupScrollBars: 'Scroll traka',
	popupStatusBar: 'Statusna traka',
	popupToolbar: 'Traka s alatima',
	popupTop: 'Gornja pozicija',
	rel: 'Veza',
	selectAnchor: 'Odaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab Indeks',
	target: 'Meta',
	targetFrame: '<okvir>',
	targetFrameName: 'Ime ciljnog okvira',
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Veza',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ubaci/promijeni vezu',
	type: 'Vrsta veze',
	unlink: 'Ukloni vezu',
	upload: 'Pošalji'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/hr.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'hr', {
	acccessKey: 'Pristupna tipka',
	advanced: 'Napredno',
	advisoryContentType: 'Savjetodavna vrsta sadržaja',
	advisoryTitle: 'Savjetodavni naslov',
	anchor: {
		toolbar: 'Ubaci/promijeni sidro',
		menu: 'Svojstva sidra',
		title: 'Svojstva sidra',
		name: 'Ime sidra',
		errorName: 'Molimo unesite ime sidra',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Ukloni sidro'
	},
	anchorId: 'Po Id elementa',
	anchorName: 'Po nazivu sidra',
	charset: 'Kodna stranica povezanih resursa',
	cssClasses: 'Stylesheet klase',
	download: 'Preuzmi na silu',
	displayText: 'Prikaži tekst',
	emailAddress: 'E-Mail adresa',
	emailBody: 'Sadržaj poruke',
	emailSubject: 'Naslov',
	id: 'Id',
	info: 'Link Info',
	langCode: 'Smjer jezika',
	langDir: 'Smjer jezika',
	langDirLTR: 'S lijeva na desno (LTR)',
	langDirRTL: 'S desna na lijevo (RTL)',
	menu: 'Promijeni link',
	name: 'Naziv',
	noAnchors: '(Nema dostupnih sidra)',
	noEmail: 'Molimo upišite e-mail adresu',
	noUrl: 'Molimo upišite URL link',
	noTel: 'Please type the phone number', // MISSING
	other: '<drugi>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Ovisno (Netscape)',
	popupFeatures: 'Mogućnosti popup prozora',
	popupFullScreen: 'Cijeli ekran (IE)',
	popupLeft: 'Lijeva pozicija',
	popupLocationBar: 'Traka za lokaciju',
	popupMenuBar: 'Izborna traka',
	popupResizable: 'Promjenjiva veličina',
	popupScrollBars: 'Scroll traka',
	popupStatusBar: 'Statusna traka',
	popupToolbar: 'Traka s alatima',
	popupTop: 'Gornja pozicija',
	rel: 'Veza',
	selectAnchor: 'Odaberi sidro',
	styles: 'Stil',
	tabIndex: 'Tab Indeks',
	target: 'Meta',
	targetFrame: '<okvir>',
	targetFrameName: 'Ime ciljnog okvira',
	targetPopup: '<popup prozor>',
	targetPopupName: 'Naziv popup prozora',
	title: 'Veza',
	toAnchor: 'Sidro na ovoj stranici',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Ubaci/promijeni vezu',
	type: 'Vrsta veze',
	unlink: 'Ukloni vezu',
	upload: 'Pošalji'
} );
